@@ -21,13 +21,14 @@ from pathlib import Path
 
 from jupyter_server.utils import url_path_join
 
-from .dependency_management import DependenciesFilesHandler, PipenvHandler, PythonVersionHandler
+from .dependency_management import YamlSpecHandler, DependencyManagementBaseHandler
+from .dependency_management import DependenciesFilesHandler, PipenvHandler, PythonVersionHandler, RootPathHandler
 from .dependency_management import ThothConfigHandler, ThothAdviseHandler, ThothInvectioHandler
 from .dependency_management import JupyterKernelHandler, DependencyInstalledHandler, DependencyInstallHandler
 
 HERE = Path(__file__).parent.resolve()
 
-__version__ = "0.6.4"
+__version__ = "0.7.0"
 
 with (HERE / "labextension" / "package.json").open() as fid:
     data = json.load(fid)
@@ -47,9 +48,7 @@ def _jupyter_server_extension_paths():
     Returns a list of dictionaries with metadata describing
     where to find the `_load_jupyter_server_extension` function.
     """
-    return [
-        {"module": "jupyterlab_requirements"}
-    ]
+    return [{"module": "jupyterlab_requirements"}]
 
 
 def _load_jupyter_server_extension(lab_app):
@@ -62,7 +61,7 @@ def _load_jupyter_server_extension(lab_app):
 
     """
     web_app = lab_app.web_app
-    host_pattern = '.*$'
+    host_pattern = ".*$"
 
     base_url = web_app.settings["base_url"]
 
@@ -70,6 +69,10 @@ def _load_jupyter_server_extension(lab_app):
 
     # Prepend the base_url so that it works in a jupyterhub setting
     custom_handlers = [
+        (
+            url_path_join(base_url, r"/jupyterlab_requirements/{}".format(YamlSpecHandler.get_resource_metadata()[0])),
+            YamlSpecHandler,
+        ),
         (url_path_join(base_url, f"/{url_path}/thoth/config"), ThothConfigHandler),
         (url_path_join(base_url, f"/{url_path}/thoth/resolution"), ThothAdviseHandler),
         (url_path_join(base_url, f"/{url_path}/thoth/invectio"), ThothInvectioHandler),
@@ -78,7 +81,12 @@ def _load_jupyter_server_extension(lab_app):
         (url_path_join(base_url, f"/{url_path}/kernel/install"), DependencyInstallHandler),
         (url_path_join(base_url, f"/{url_path}/kernel/python"), PythonVersionHandler),
         (url_path_join(base_url, f"/{url_path}/kernel/create"), JupyterKernelHandler),
+        (url_path_join(base_url, f"/{url_path}/file/directory"), RootPathHandler),
         (url_path_join(base_url, f"/{url_path}/file/dependencies"), DependenciesFilesHandler),
+        (
+            url_path_join(base_url, r"/jupyterlab_requirements/jupyterlab_requirements/tasks/%s" % r"(?P<index>\d+)"),
+            DependencyManagementBaseHandler,
+        ),  # GET / DELETE
     ]
 
     web_app.add_handlers(host_pattern, custom_handlers)
