@@ -19,15 +19,14 @@
 import json
 import os
 import logging
+import subprocess
 
 from pathlib import Path
 
 from jupyter_server.base.handlers import APIHandler
 from tornado import web
 
-from thamos.lib import load_files
 from thoth.python import Project
-from jupyterlab_requirements.dependency_management.common import select_complete_path
 
 _LOGGER = logging.getLogger("jupyterlab_requirements.dependencies_files_handler")
 
@@ -35,31 +34,6 @@ _LOGGER = logging.getLogger("jupyterlab_requirements.dependencies_files_handler"
 class DependenciesFilesHandler(APIHandler):
     """Dependencies files handler to store, extract software stack."""
 
-    @web.authenticated
-    def get(self):
-        """Retrieve requirements files from local disk."""
-        dependencies = {
-            "error": False,
-            "requirements": "",
-            "requirements_lock": ""
-        }
-
-        requirements_format = "pipenv"
-
-        try:
-            project = load_files(requirements_format=requirements_format)
-            requirements = project.pipfile.to_dict()
-            requirements_lock = project.pipfile_lock.to_dict()
-
-            dependencies['requirements'] = requirements
-            dependencies['requirements_lock'] = requirements_lock
-
-        except Exception as e:
-            _LOGGER.warning(e)
-            dependencies["error"] = True
-
-        self.finish(json.dumps(dependencies))
-
     @web.authenticated
     def post(self):
         """Store requirements file to disk."""
@@ -68,21 +42,20 @@ class DependenciesFilesHandler(APIHandler):
 
         # Path of the repo where we need to store
         path_to_store: str = input_data["path_to_store"]
-        using_home_path_base: bool = input_data["using_home_path_base"]
 
         kernel_name: str = input_data["kernel_name"]
         requirements: str = input_data["requirements"]
         requirements_lock: str = input_data["requirement_lock"]
+        complete_path: str = input_data["complete_path"]
 
-        home = Path.home()
+        env_path = Path(complete_path).joinpath(path_to_store).joinpath(kernel_name)
 
-        if using_home_path_base:
-            env_path =  home.joinpath(path_to_store).joinpath(kernel_name)
-        else:
-            complete_path = select_complete_path()
-            env_path = complete_path.joinpath(path_to_store).joinpath(kernel_name)
+        _LOGGER.info("Path used to store dependencies is: %r", env_path.as_posix())
+
+        # Delete and recreate folder
+        if env_path.exists():
+            _ = subprocess.call(f"rm -rf ./{kernel_name} ", shell=True, cwd=Path(complete_path).joinpath(path_to_store))
 
-        _LOGGER.info("path used to store dependencies is: %r", env_path.as_posix())
         env_path.mkdir(parents=True, exist_ok=True)
 
         os.chdir(env_path)
@@ -96,12 +69,7 @@ class DependenciesFilesHandler(APIHandler):
 
         if requirements_format == "pipenv":
             _LOGGER.debug("Writing to Pipfile/Pipfile.lock in %r", env_path)
-            project.to_files(
-                pipfile_path=pipfile_path,
-                pipfile_lock_path=pipfile_lock_path
-            )
+            project.to_files(pipfile_path=pipfile_path, pipfile_lock_path=pipfile_lock_path)
 
         os.chdir(initial_path)
-        self.finish(json.dumps({
-            "message": f"Successfully stored requirements at {env_path}!"
-        }))
+        self.finish(json.dumps({"message": f"Successfully stored requirements at {env_path}!"}))
