@@ -23,7 +23,7 @@ import subprocess
 
 from pathlib import Path
 
-from jupyter_server.base.handlers import APIHandler
+from jupyterlab_requirements.dependency_management.base import DependencyManagementBaseHandler
 from tornado import web
 
 from thoth.python import Pipfile, PipfileLock
@@ -33,14 +33,21 @@ from virtualenv import cli_run
 _LOGGER = logging.getLogger("jupyterlab_requirements.pipenv")
 
 
-class PipenvHandler(APIHandler):
+class PipenvHandler(DependencyManagementBaseHandler):
     """pipenv handler to receive optimized software stack."""
 
     @web.authenticated
-    async def post(self):
+    def post(self):
+        """Post method for class."""
+        input_data = self.get_json_body()
+
+        task_index = self._tasks.create_task(self.lock_using_pipenv, input_data)
+
+        self.redirect_to_task(task_index)
+
+    async def lock_using_pipenv(self, input_data):
         """Lock and install dependencies using pipenv."""
         initial_path = Path.cwd()
-        input_data = self.get_json_body()
 
         kernel_name: str = input_data["kernel_name"]
         requirements: dict = json.loads(input_data["requirements"])
@@ -51,12 +58,12 @@ class PipenvHandler(APIHandler):
 
         # Delete and recreate folder
         if not env_path.exists():
-            _ = subprocess.call(
-                f"rm -rf ./{kernel_name} ", shell=True, cwd=complete_path)
+            _ = subprocess.call(f"rm -rf ./{kernel_name} ", shell=True, cwd=complete_path)
 
         env_path.mkdir(parents=True, exist_ok=True)
 
-        result = {"requirements_lock": "", "error": False}
+        result = {"requirements_lock": "", "error": False, "error_msg": ""}
+        returncode = 0
 
         ## Create virtualenv
         cli_run([str(env_path)])
@@ -75,30 +82,40 @@ class PipenvHandler(APIHandler):
         try:
             # TODO: check if pipenv is installed
             subprocess.run(
-                f". {kernel_name}/bin/activate && cd {kernel_name} && pip install pipenv",
-                cwd=complete_path,
-                shell=True
+                f". {kernel_name}/bin/activate && cd {kernel_name} && pip install pipenv", cwd=complete_path, shell=True
             )
-        except Exception as pipenv_error:
-            _LOGGER.warning("error installing pipenv: %r", pipenv_error)
-            result['error'] = True
+        except Exception as pipenv_install_error:
+            _LOGGER.warning("error installing pipenv: %r", pipenv_install_error)
+            result["error"] = True
+            result["error_msg"] = pipenv_install_error
+            returncode = 1
             os.chdir(initial_path)
-            self.finish(json.dumps(result))
+
+            return returncode, result
 
         try:
-            subprocess.run(
+            output = subprocess.run(
                 f". {kernel_name}/bin/activate && cd {kernel_name} && pipenv lock",
-                env=dict(os.environ, PIPENV_CACHE_DIR='/tmp'),
+                env=dict(os.environ, PIPENV_CACHE_DIR="/tmp"),
                 cwd=complete_path,
-                shell=True
+                shell=True,
+                capture_output=True,
             )
         except Exception as pipenv_error:
             _LOGGER.warning("error locking dependencies using Pipenv: %r", pipenv_error)
-            result['error'] = True
+            result["error"] = True
+            result["error_msg"] = str(pipenv_error)
+            returncode = 1
+
+        if output.returncode != 0:
+            _LOGGER.warning("error locking dependencies using Pipenv: %r", output.stderr)
+            result["error"] = True
+            result["error_msg"] = str(output.stderr)
+            returncode = 1
 
         os.chdir(env_path)
 
-        if not result['error']:
+        if not result["error"]:
 
             pipfile_lock_path = env_path.joinpath("Pipfile.lock")
 
@@ -116,7 +133,9 @@ class PipenvHandler(APIHandler):
 
             else:
                 _LOGGER.warning("Pipfile.lock cannot be found at: %r", str(pipfile_lock_path))
-                result['error'] = True
+                result["error"] = True
+                result["error_msg"] = "Error retrieving Pipfile.lock created from pipenv."
 
         os.chdir(initial_path)
-        self.finish(json.dumps(result))
+
+        return returncode, result
