@@ -235,6 +235,10 @@ export async function _handle_requirements(
                 _.set(identified_packages, "scikit-learn", "*")
               }
 
+              else if ( library == "dotenv" ) {
+                _.set(identified_packages, "python-dotenv", "*")
+              }
+
               else {
                 _.set(identified_packages, library, "*")
               }
@@ -494,7 +498,7 @@ export async function store_dependencies_on_disk (
     requirements: Requirements,
     requirements_lock: RequirementsLock,
     path_to_store: string,
-    using_home_path_base: boolean
+    complete_path: string
   ) {
     // TODO: Requested from the user (in this case it is to install them)
     const store_message: string = await store_dependencies(
@@ -502,7 +506,7 @@ export async function store_dependencies_on_disk (
         JSON.stringify(requirements),
         JSON.stringify(requirements_lock),
         path_to_store,
-        using_home_path_base
+        complete_path
     );
 
     console.debug("Store message", store_message);
