@@ -9,35 +9,46 @@
  * @since  0.0.1
  */
 
-import { requestAPI, THOTH_JUPYTER_INTEGRATION_API_BASE_NAME } from './handler';
+import { requestAPI, THOTH_JUPYTER_INTEGRATION_API_BASE_NAME, AsyncTaskHandler } from './handler';
 import * as utils from "./utils";
 
 /**
  * Function: Install dependencies in the new kernel.
  */
 
-export async function install_packages (
+ export async function install_packages(
   kernel_name: string,
   resolution_engine: string,
-  init: RequestInit = {},
-): Promise<string> {
-
-  // POST request
-  const dataToSend = {
-    kernel_name: kernel_name,
-    resolution_engine: resolution_engine
-  };
-
-  const endpoint: string = 'kernel/install'
-
+): Promise<string|undefined> {
   try {
-    const message = await requestAPI<any>(endpoint, {
+    // POST request
+    const dataToSend = {
+      kernel_name: kernel_name,
+      resolution_engine: resolution_engine
+    };
+    const request: RequestInit = {
       body: JSON.stringify(dataToSend),
       method: 'POST'
-    });
-    return message;
-  } catch (reason) {
-    console.error('Error on POST /' + THOTH_JUPYTER_INTEGRATION_API_BASE_NAME + '/' + endpoint + ':', reason);
+    };
+    var endpoint = "kernel/install"
+    const { promise } = AsyncTaskHandler(
+      endpoint,
+      request
+    );
+    const response = await promise;
+    if (response) {
+      // this._uiStateChanged.emit({
+      //   type: 'installed'
+      // });
+      return JSON.parse(JSON.stringify(response));
+    }
+  } catch (error) {
+      let message: string = error.message || error.toString();
+
+      if ( message !== 'cancelled') {
+        console.error('Error on POST /' + THOTH_JUPYTER_INTEGRATION_API_BASE_NAME + '/' + endpoint + ':', message);
+        message = `An error occurred while installing dependencies.`;
+    }
   }
 }
 
@@ -124,7 +135,7 @@ export async function store_dependencies (
     requirements: string,
     requirement_lock: string,
     path_to_store: string = ".local/share/thoth/kernels",
-    using_home_path_base: boolean = true,
+    complete_path: string,
     init: RequestInit = {},
   ): Promise<string> {
 
@@ -134,7 +145,7 @@ export async function store_dependencies (
       requirements: requirements,
       requirement_lock: requirement_lock,
       path_to_store: path_to_store,
-      using_home_path_base: using_home_path_base
+      complete_path: complete_path
     };
 
     const endpoint: string = 'file/dependencies'
@@ -178,3 +189,22 @@ export async function gather_library_usage(
   }
 
 }
+
+/**
+ * Function: Attempt to discover root directory for the project.
+ */
+
+export async function discover_root_directory(
+  init: RequestInit = {},
+): Promise<string> {
+  const endpoint: string = 'file/directory'
+
+  try {
+    const root_directory = await requestAPI<any>(endpoint, {
+      method: 'GET'
+    });
+    return JSON.parse(JSON.stringify(root_directory));
+  } catch (reason) {
+    console.error('Error on GET /' + THOTH_JUPYTER_INTEGRATION_API_BASE_NAME + '/' + endpoint + ':', reason);
+  }
+}
